#
# spec file for package imapfilter
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           imapfilter
Version:        2.8.2
Release:        1.1
Summary:        A mail filtering utility
License:        MIT
Group:          Productivity/Networking/Email/Utilities
URL:            https://github.com/lefcha/imapfilter
Source:         https://github.com/lefcha/imapfilter/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  lua-devel >= 5.1
BuildRequires:  openssl-devel
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig

%description
IMAPFilter is a mail filtering utility. It connects to remote mail
servers using the Internet Message Access Protocol (IMAP), sends
searching queries to the server and processes mailboxes based on the
results. It can be used to delete, copy, move, flag, etc. messages
residing in mailboxes at the same or different mail servers. The 4rev1
and 4 versions of the IMAP protocol are supported.

IMAPFilter uses the Lua programming language as a configuration and
extension language.

%prep
%setup -q

%build
%make_build PREFIX="%{_prefix}" MANDIR="%{_mandir}" MYCFLAGS="%{optflags} -I%{lua_incdir}"

%install
%make_install PREFIX="%{_prefix}" MANDIR="%{_mandir}"

%files
%{_bindir}/imapfilter
%dir %{_datadir}/imapfilter
%{_datadir}/imapfilter/*.lua
%{_mandir}/man1/imapfilter.1%{?ext_man}
%{_mandir}/man5/imapfilter_config.5%{?ext_man}
%license LICENSE
%doc README AUTHORS NEWS

%changelog
* Sat Dec 30 2023 Dirk Müller <dmueller@suse.com>
- update to 2.8.2:
  * Add IMAP support for UTF-8 (RFC 6855) when "charset" is
    set to "UTF-8"
  * Don't use FETCH FAST macro use for better compatibility
  * Bug fix; recovery mechanism error on Lua 5.1
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.8.1:
  * Add support for non-write actions on read-only mailboxes.
  * Add new parameter to write process ID (PID) to file.
  * New, more advanced, robust, and flexible recovery
    mechanism, replaces the old automatic recovery functionality.
    Note that, the config must be updated to use the new mechanism,
    otherwise no recovery will take place on errors.
  * Fix potential failure when deleting mailbox while
    mailbox is selected.
* Sat Oct 22 2022 Arun Persaud <arun@gmx.de>
- update to 2.7.6:
  * Support building with OpenSSL 3.0.0 and later.
  * Several minor improvements to documentation and example code.
  * Removed deprecated CRAM-MD5 mechanism.
  * Bug fix; session was destroyed incorrectly on login failures.
  * Bug fix; potential session management problems.
* Sun Dec 20 2020 Dirk Müller <dmueller@suse.com>
- update to 2.7.5:
  * New "hostnames" option can be used to disable hostname validation.
  * Bug fix; "certificates" option incorrectly controlled hostname validation.
* Thu Nov 26 2020 Arun Persaud <arun@gmx.de>
- update to version 2.7.4:
  * Bug fix; incorrect argument to regular expression compile
    function.
* Sat Nov 14 2020 Arun Persaud <arun@gmx.de>
- update to version 2.7.3:
  * Bug fix; incorrect free of compiled pattern.
  * Unexpected network errors and IMAP BYE are now logged.
- changes from version 2.7.2:
  * Makefile is back to being Lua version agnostic.
- changes from version 2.7.1:
  * Makefile now builds with Lua 5.4 and PCRE2.
- changes from version 2.7 :
  * Lua 5.4 compatibility (the codebase can still be compiled with
    versions 5.3, 5.2 and 5.1).
  * PCRE2 compatibility (version 10.00 and later)
  * New error code is returned if certificate verify fails.
  * Bug fix; add missing truststore option from brief usage message.
* Sun Dec 29 2019 Arun Persaud <arun@gmx.de>
- update to version 2.6.16:
  * Bug fix; escape the double-quote character in passwords.
- changes from version 2.6.15:
  * Bug fix; try to setup both a CA file and path for SSL validations.
* Sat Nov  9 2019 Arun Persaud <arun@gmx.de>
- update to version 2.6.14
  * Bug fix; OpenSSL version mess up for SSL hostname validation.
* Sat Sep 21 2019 Arun Persaud <arun@gmx.de>
- update to version 2.6.13:
  * Support for SSL hostname validation.
* Sat Nov  3 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * added README AUTHORS LICENSE NEWS to %%doc
  * ran spec-cleaner
- update to version 2.6.12:
  * Support for Server Name Indication (SNI).
  * The searching methods return values are described in the config
    man page.
  * Example of using the enter_idle() function in the sample extend
    file.
* Thu Mar  1 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.6.11:
  * Support for interrupting IDLE mode with SIGUSR1/SIGUSR2.
  * New "persist" option to try to recover a connection indefinitely.
  * New "range" option to limit messages included in a range.
  * Bug fix; always close selected mailbox before check_status().
  * Bug fix; closing of selected mailbox twice with fetch_message().
* Wed Sep  6 2017 jengelh@inai.de
- Clean out old constructs from specfile.
* Tue Aug 22 2017 crrodriguez@opensuse.org
- fix build failure with lua 5.3. missing include directory.
* Tue Feb 21 2017 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.6.10:
  * Bug fix; segmentation fault on some OpenSSL builds.
- changes from version 2.6.9:
  * Bug fix; possible problem during STARTTLS negotiation.
- changes from version 2.6.8:
  * Support building with OpenSSL 1.1.0.
* Thu Jun 23 2016 arun@gmx.de
- update to version 2.6.7:
  * A dry-run mode that disables all actions that modify data.
  * Bug fix; handle IDLE untagged responses that are received in
    pieces.
* Sat Feb  6 2016 arun@gmx.de
- update to version 2.6.6:
  * Bug fix; print an error message if "ssl" has been set to "ssl3".
- changes from version 2.6.5:
  * Possible to build again with OpenSSL when support for SSL 3.0 is
    disabled.
- changes from version 2.6.4:
  * Support for OAuth 2.0 and the XOAUTH2 authentication mechanism.
* Wed Oct  7 2015 arun@gmx.de
- specfile: update copyright year
- upgrade to version 2.6.3:
  * Support for loading a default CA certificates file.
  * A new has_unkeyword() method to search messages without a keyword
    flag set.
  * Bug fix; double quotation around keyword sent by the has_flag()
    method.
- changes from version 2.6.2:
  * Bug fix; drop connection on local certificate mismatch.
- changes from version 2.6.1:
  * Support for loading the system's CA certificates from a file.
  * Bug fix; flusing of standard output/error in a some cases.
- changes from version 2.6:
  * Optimizations that vastly improve performance of the
    meta-searching functionality, by making subsequent search requests
    limit their scope based on the results already returned by
    previous requests (previously this was the case only for the
    match_*() methods).
  * Lua 5.3 compatibility (the codebase can still be compiled with
    versions 5.2 and 5.1).
  * A new "limit" option can be used as a work-around for problems
    that some servers have with long requests.
  * The documentation now clarifies how to make the client block
    indefinitely.
  * Bug fix; the check_status() method now returns 4 numbers on error
    as described in the documentation (just negative values in this
    case).
  * Bug fix; flushing of default output on password prompt.
  * Bug fix; program fault when very long requests were to be sent.
* Sat Dec  6 2014 arun@gmx.de
- specfile: update copyright year
- update to version 2.5.7
  * Support for automatic validation of SSL connections, using the
  operating system's installed trusted CA certificates (usually from
  authorities that are shipped with web browsers).
  * A new "wakeonany" option makes it possible to end IDLE mode on any
  event, not just on new messages.
  * A new "reenter" option controls whether IDLE mode should be
  re-entered, after the recovery of the session, which makes it
  possible to continue with the execution of the next line in the
  configuration file.
  * The documentation now mentions that the contain_*() methods do
  case-insensitive searching (an IMAP limitation).
  * The documentation now has a better explanation of the arrived_*()
  and sent_*() methods.
  * Bug fix; the value returned by the copy method was incorrect in
  some cases.
* Thu Dec  5 2013 arun@gmx.de
- update to IMAPFilter 2.5.6 - 27 Oct 2013
  * Possible to build again with OpenSSL older than version 1.0.1 (was a
    requirement for the previous release due to new protocols TLS 1.1/1.2).
  * Support for reading the configuration from the standard input stream.
  * New makefile dist target, which can be used to create distribution archives.
* Mon Jul 15 2013 arun@gmx.de
- updated to IMAPFilter 2.5.5 - 8 Jun 2013
  - Work-around for some servers that send an unexpected APPEND response.
  - The serial number of the certificates is taken into account, because some
    servers send different certificates with the same subject and issuer.
  - Details of the stored certificates are written to the certificates file, in
    order to make it easier to distinguish each of them.
  - Support for TLS versions 1.1 and 1.2 for secure connections.
* Fri Apr 19 2013 arun@nubati.net
- updated to IMAPFilter 2.5.4 - 9 Apr 2013
  - Some server responses are now parsed less stricly.
  - More detailed information is now printed when there's an error.
  - Bug fix; various corrections in the recovery mechanism.
* Wed Jul 25 2012 arun@nubati.net
- updated to version 2.5.3
  - New implementation for international mailbox names.
  - Bug fix; wrong variable name in one of the examples on extending.
  - Bug fix; an OpenSSL compilation warning.
* Sun Apr 22 2012 puzel@suse.com
- update to version 2.5.2
  - Persistent errors or connection failures are now ignored when
    running in daemon mode, and a reconnection is attempted during
    the next loop iteration.
  - Bug fix; problems with failure handling during login/logout.
* Tue Feb 28 2012 arun@nubati.net
- updated to version 2.5.1 (taken from the NEWS file)
  IMAPFilter 2.5.1 - 27 Feb 2012
  - Support for recovery of a session after a BYE response is received.
  - Option to control in which cases a terminated session will be restored.
  - Bug fix; a BYE response could sometimes get incorrectly ignored.
  IMAPFilter 2.5 - 23 Feb 2012
  - Support for recovery of a session when a network failure is encountered,
    and other robustness improvements.
  - Informational messages are printed also for the fetch and append methods.
  - Lua 5.2 compatibility, while the codebase can still be compiled with
    version 5.1.
  - The OpenSSL library is now a mandatory build requirement.
  - Bug fix; unrecoverable login failures did not result in aborting of the
    execution of the configuration.
  - Bug fix; when messages were appended to a mailbox that did not exist, it
    failed to create the mailbox and then retry the appending.
  - Bug fix; misleading errors were printed on some SSL failures.
  - Bug fix; protected call of the commands to execute in the daemon function
    could hide important failures.
  - Bug fix; the man page had an incorrect description of the -d option.
  * Support for the old deprecated 1.x configuration format has been removed,
    and the current 2.x format can only be executed from now on.
  IMAPFilter 2.4.2 - 19 Jan 2012
  - Bug fix; some ASCII characters in mailbox names were incorrectly converted
    to UTF-7.
  IMAPFilter 2.4.1 - 8 Dec 2011
  - Bug fix; become_daemon() failure.
  IMAPFilter 2.4 - 6 Dec 2011
  - Support for non-ASCII mailbox names.
  - New environment variable to set the configuration directory.
  - Bug fix; parsing of some server responses was broken since the previous
    release.
  - Bug fix; the match_field() method matched on the whole header field,
    instead of only the header field body.
  - Bug fix; debug file check caused printing of a misleading error message.
  - Bug fix; typo error in a configuration man page example.
* Sun Feb 26 2012 dmueller@suse.de
- fix build
* Sun Oct 23 2011 arun@nubati.net
- Update to version 2.3 (taken from the NEWS file)
  IMAPFilter 2.3 - 6 Aug 2011
  - Support for appending/uploading messages to mailboxes.
  - Debug file option now takes filename argument.
  - New simplified configuration and building procedure.
  - Bug fix; in some cases a mailbox was incorrectly assumed selected.
  - Bug fix; in some cases server capabilities needed update after login.
  - Bug fix; timeout problem with CRAM-MD5 authentication.
  - Bug fix; some servers send non-ASCII characters in their responses.
  IMAPFilter 2.2.3 - 6 Mar 2011
  - Project moved to GitHub.
  - Changed file and directory structure.
  - The next UID is returned as an additional return value of check_status().
  - All processing methods now return a boolean based on their success.
  - Bug fix; a lost connection is now handled better by trying to reconnect.
  - Bug fix; in some cases in IDLE a message had arrived but was ignored.
  - Bug fix; in some servers the initial IDLE reply wasn't handled correctly.
  - Bug fix; typo errors in the documentation.
* Fri Nov  5 2010 hvogel@novell.com
- Update to version 2.2.2
  * Bug fix; a couple of errors in the extending examples file.
  * A global option for the IDLE refreshing interval was added.
  * Bug fix; more detailed reporting when SSL socket errors occur.
* Thu Dec 31 2009 pascal.bleser@opensuse.org
- update to 2.2:
  * support for combining searching methods in multiple mailboxes
    at the same or different accounts and processing of the results
    in bulk
  * support for meta-searching that allows searching on the
    previous searching results
* Tue Nov 24 2009 chris@computersalat.de
- fix build for SLE_10
  o lua >= 5.1
- spec mods
  o fix header
  o sorted TAGS
  * fix Summary
  o removed changes from spec
* Mon Nov 23 2009 pascal.bleser@opensuse.org
- update to 2.1:
  * add support for the IMAP IDLE extension
  * add new methods to fetch parts of messages along with the body
    structure of messages
  * add global option for the character to be used during searching
  * minor bugfixes
* Fri Mar 28 2008 coolo@suse.de
- remove explicit lib require
* Mon Feb 18 2008 mskibbe@suse.de
- update to version 2.0.10 which:
  o Bug fix; failed a great number (tens of thousands) of commands
    were exchanged with an IMAP server
  o Bug fix; failed to fetch the body of some messages in some
    extremely rare occasions
  o Bug fix; the description for the contain_header() method was
    clarified
* Mon Jan  7 2008 mskibbe@suse.de
- update to version 2.0.9 which:
  o on some platforms it is necessary to link against the math
    library
  o the match_*() methods failed to match messages.
  o the match_*() methods failed with an error when no messages
    matched.
  o note added in the documentation about the need to use double
    backslashes inside of regular expression patterns.
* Mon Oct  8 2007 mskibbe@suse.de
- update to version 2.0.6 which:
  o fix a bug that the select_all() method sent an incorrect format
    and this caused an error in some mail servers.
* Fri Oct  5 2007 mmaher@suse.de
- update to version 2.0.5 which:
  * Bug fix; an error in the sample extensions file.
  * Bug fix; typo errors in the manual page.
  * The documentation was updated with details and examples on how to
    access mailboxes inside folders.
  * Examples were added on how to define composite filters that include
    multiple searching rules.
* Fri Sep 28 2007 mskibbe@suse.de
- update to version 2.0.4 which
  * Bug fix; the send_query() method didn't return the special
    form of table that the rest of the searching methods did.
  * An additional searching method has been added to search for
    keyword flags set.
  * A new variable that was added to the Makefile makes it possible
    to set an alternative environment for the installation path.
- delete obsolete patches
* Tue Jul 31 2007 mskibbe@suse.de
- update to version 2.0.3 which:
  * New, more powerful, feature rich and yet simpler configuration
    file
  * Easier object oriented view of accounts and mailboxes.
  * Simpler approach to filters, with infix logical or/and/not
    operators
  * No more need to mess with server search queries
  * More and simpler functions instead of few and complicated ones
  * More feature complete interface that can now even manipulate
    mailboxes
  * Regular expressions integrated into the searching interface
  * Effective caching subsystem when fetching message parts
  * Can still read old version 1.x configuration files
    for compatibility
* Thu Jan 11 2007 mskibbe@suse.de
- fix segfault at start
* Fri Nov 17 2006 mskibbe@suse.de
- fix requires
* Thu Oct 19 2006 ro@suse.de
- use pkgconfig to get lua libs
* Wed Aug  2 2006 mskibbe@suse.de
- fixed some compiler warnings
- add RPM_OPT_FLAGS to make
- update to version 1.2.2 which
  o Bug fix; a mix up of connections could happen in certain
    circumstances, when a hostname and/or username was a prefix of
    another hostname and/or username respectively, or when the same
    hostname and username was used to connect to a different port.
  o Bug fix; the list()/lsub() functions parsed mailboxes/folders
    whose names contained spaces incorrectly.
  o The list() function now does not return the folder itself, when
    listing mailboxes inside a specific folder.
  o It is now possible to define new user keywords for messages
    inside a mailbox, apart from the standard system flags.
* Mon Jul 17 2006 mskibbe@suse.de
- create package
- add fix to build in BUILDROOT
